@@ -12,7 +12,7 @@ import urllib
 import urllib2
 import re
 
-__version__  = '0.10.8'
+__version__  = '0.10.9'
 __author__ = "Hiroki Ohtani (liris.pp [at] gmail.com)"
 __copyright__ = "Copyright (c) 2006 Hiroki Ohtani"
 __license__ = "LGPL"
@@ -872,7 +872,7 @@ class Node(object):
                 if lines[-1] == '':
                     del lines[-1]
                 section = '\n'.join(lines)
-                _split = section.split('\n\n')
+                _split = section.split('\n\n', 1)
                 if len(_split) != 2:
                     return None
                 rdlines = _split[0].splitlines()
