@@ -172,15 +172,15 @@ class NodeTestCase(unittest.TestCase):
         self.assertNotEqual(len(nres.docs), 0)
         
     def testNode(self):
-        print self.node.get_name()
-        print self.node.get_label()
-        print self.node.get_doc_num()
-        print self.node.get_word_num()
-        print self.node.get_size()
-        print self.node.get_cache_usage()
-        print self.node.get_admins()
-        print self.node.get_users()
-        print self.node.get_links()
+        print(self.node.get_name())
+        print(self.node.get_label())
+        print(self.node.get_doc_num())
+        print(self.node.get_word_num())
+        print(self.node.get_size())
+        print(self.node.get_cache_usage())
+        print(self.node.get_admins())
+        print(self.node.get_users())
+        print(self.node.get_links())
 
 if __name__ == "__main__":
     unittest.main()
